==> itk_montage-0.5.2-cp37-cp37m-win_amd64.whl: itk/Configuration/MontageConfig.py <==
depends = ('ITKPyBase', 'ITKTransform', 'ITKImageFrequency', 'ITKIOImageBase', 'ITKFFT', 'ITKCommon', )
templates = (
  ('Image', 'itk::Image', 'itkImageCD2', False, 'std::complex< double >, 2'),
  ('vector', 'std::vector', 'vectoritkImageCD2', False, 'itk::Image< std::complex< double >, 2  > '),
  ('Image', 'itk::Image', 'itkImageCD3', False, 'std::complex< double >, 3'),
  ('vector', 'std::vector', 'vectoritkImageCD3', False, 'itk::Image< std::complex< double >, 3  > '),
  ('ImageSource', 'itk::ImageSource', 'itkImageSourceICD2', False, 'itk::Image< std::complex< double >, 2 >'),
  ('ImageSource', 'itk::ImageSource', 'itkImageSourceICD3', False, 'itk::Image< std::complex< double >, 3 >'),
  ('ImageToImageFilter', 'itk::ImageToImageFilter', 'itkImageToImageFilterICD2ICD2', False, 'itk::Image< std::complex< double >, 2 >, itk::Image< std::complex< double >, 2 >'),
  ('ImageToImageFilter', 'itk::ImageToImageFilter', 'itkImageToImageFilterICD3ICD3', False, 'itk::Image< std::complex< double >, 3 >, itk::Image< std::complex< double >, 3 >'),
  ('PhaseCorrelationOperator', 'itk::PhaseCorrelationOperator', 'itkPhaseCorrelationOperatorF2', True, 'float, 2'),
  ('PhaseCorrelationOperator', 'itk::PhaseCorrelationOperator', 'itkPhaseCorrelationOperatorD2', True, 'double, 2'),
  ('PhaseCorrelationOperator', 'itk::PhaseCorrelationOperator', 'itkPhaseCorrelationOperatorF3', True, 'float, 3'),
  ('PhaseCorrelationOperator', 'itk::PhaseCorrelationOperator', 'itkPhaseCorrelationOperatorD3', True, 'double, 3'),
  ('PhaseCorrelationOptimizer', 'itk::PhaseCorrelationOptimizer', 'itkPhaseCorrelationOptimizerICF2', True, 'itk::Image< std::complex< float >,2 >'),
  ('PhaseCorrelationOptimizer', 'itk::PhaseCorrelationOptimizer', 'itkPhaseCorrelationOptimizerIF2', True, 'itk::Image< float,2 >'),
  ('PhaseCorrelationOptimizer', 'itk::PhaseCorrelationOptimizer', 'itkPhaseCorrelationOptimizerID2', True, 'itk::Image< double,2 >'),
  ('PhaseCorrelationOptimizer', 'itk::PhaseCorrelationOptimizer', 'itkPhaseCorrelationOptimizerICD2', True, 'itk::Image< std::complex< double >, 2 >'),
  ('PhaseCorrelationOptimizer', 'itk::PhaseCorrelationOptimizer', 'itkPhaseCorrelationOptimizerICF3', True, 'itk::Image< std::complex< float >,3 >'),
  ('PhaseCorrelationOptimizer', 'itk::PhaseCorrelationOptimizer', 'itkPhaseCorrelationOptimizerIF3', True, 'itk::Image< float,3 >'),
  ('PhaseCorrelationOptimizer', 'itk::PhaseCorrelationOptimizer', 'itkPhaseCorrelationOptimizerID3', True, 'itk::Image< double,3 >'),
  ('PhaseCorrelationOptimizer', 'itk::PhaseCorrelationOptimizer', 'itkPhaseCorrelationOptimizerICD3', True, 'itk::Image< std::complex< double >, 3 >'),
  ('PhaseCorrelationImageRegistrationMethodEnums', 'itk::PhaseCorrelationImageRegistrationMethodEnums', 'itkPhaseCorrelationImageRegistrationMethodEnums', False),
  ('PhaseCorrelationImageRegistrationMethod', 'itk::PhaseCorrelationImageRegistrationMethod', 'itkPhaseCorrelationImageRegistrationMethodISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('PhaseCorrelationImageRegistrationMethod', 'itk::PhaseCorrelationImageRegistrationMethod', 'itkPhaseCorrelationImageRegistrationMethodIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('PhaseCorrelationImageRegistrationMethod', 'itk::PhaseCorrelationImageRegistrationMethod', 'itkPhaseCorrelationImageRegistrationMethodIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('PhaseCorrelationImageRegistrationMethod', 'itk::PhaseCorrelationImageRegistrationMethod', 'itkPhaseCorrelationImageRegistrationMethodIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('PhaseCorrelationImageRegistrationMethod', 'itk::PhaseCorrelationImageRegistrationMethod', 'itkPhaseCorrelationImageRegistrationMethodID2ID2', True, 'itk::Image< double,2 >, itk::Image< double,2 >'),
  ('PhaseCorrelationImageRegistrationMethod', 'itk::PhaseCorrelationImageRegistrationMethod', 'itkPhaseCorrelationImageRegistrationMethodISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('PhaseCorrelationImageRegistrationMethod', 'itk::PhaseCorrelationImageRegistrationMethod', 'itkPhaseCorrelationImageRegistrationMethodIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('PhaseCorrelationImageRegistrationMethod', 'itk::PhaseCorrelationImageRegistrationMethod', 'itkPhaseCorrelationImageRegistrationMethodIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('PhaseCorrelationImageRegistrationMethod', 'itk::PhaseCorrelationImageRegistrationMethod', 'itkPhaseCorrelationImageRegistrationMethodIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('PhaseCorrelationImageRegistrationMethod', 'itk::PhaseCorrelationImageRegistrationMethod', 'itkPhaseCorrelationImageRegistrationMethodID3ID3', True, 'itk::Image< double,3 >, itk::Image< double,3 >'),
  ('DataObjectDecorator', 'itk::DataObjectDecorator', 'itkDataObjectDecoratorTTD2', False, 'itk::TranslationTransform< double , 2 >'),
  ('DataObjectDecorator', 'itk::DataObjectDecorator', 'itkDataObjectDecoratorTTD3', False, 'itk::TranslationTransform< double , 3 >'),
  ('SimpleDataObjectDecorator', 'itk::SimpleDataObjectDecorator', 'itkSimpleDataObjectDecoratorPD2', False, 'itk::Point< double , 2 >'),
  ('SimpleDataObjectDecorator', 'itk::SimpleDataObjectDecorator', 'itkSimpleDataObjectDecoratorPD3', False, 'itk::Point< double , 3 >'),
  ('MaxPhaseCorrelationOptimizerEnums', 'itk::MaxPhaseCorrelationOptimizerEnums', 'itkMaxPhaseCorrelationOptimizerEnums', False),
  ('MaxPhaseCorrelationOptimizer', 'itk::MaxPhaseCorrelationOptimizer', 'itkMaxPhaseCorrelationOptimizerPCIRMISS2ISS2', True, 'itk::PhaseCorrelationImageRegistrationMethod< itk::Image< signed short,2 >, itk::Image< signed short,2 > >'),
  ('MaxPhaseCorrelationOptimizer', 'itk::MaxPhaseCorrelationOptimizer', 'itkMaxPhaseCorrelationOptimizerPCIRMIUC2IUC2', True, 'itk::PhaseCorrelationImageRegistrationMethod< itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 > >'),
  ('MaxPhaseCorrelationOptimizer', 'itk::MaxPhaseCorrelationOptimizer', 'itkMaxPhaseCorrelationOptimizerPCIRMIUS2IUS2', True, 'itk::PhaseCorrelationImageRegistrationMethod< itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 > >'),
  ('MaxPhaseCorrelationOptimizer', 'itk::MaxPhaseCorrelationOptimizer', 'itkMaxPhaseCorrelationOptimizerPCIRMIF2IF2', True, 'itk::PhaseCorrelationImageRegistrationMethod< itk::Image< float,2 >, itk::Image< float,2 > >'),
  ('MaxPhaseCorrelationOptimizer', 'itk::MaxPhaseCorrelationOptimizer', 'itkMaxPhaseCorrelationOptimizerPCIRMID2ID2', True, 'itk::PhaseCorrelationImageRegistrationMethod< itk::Image< double,2 >, itk::Image< double,2 > >'),
  ('MaxPhaseCorrelationOptimizer', 'itk::MaxPhaseCorrelationOptimizer', 'itkMaxPhaseCorrelationOptimizerPCIRMISS3ISS3', True, 'itk::PhaseCorrelationImageRegistrationMethod< itk::Image< signed short,3 >, itk::Image< signed short,3 > >'),
  ('MaxPhaseCorrelationOptimizer', 'itk::MaxPhaseCorrelationOptimizer', 'itkMaxPhaseCorrelationOptimizerPCIRMIUC3IUC3', True, 'itk::PhaseCorrelationImageRegistrationMethod< itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 > >'),
  ('MaxPhaseCorrelationOptimizer', 'itk::MaxPhaseCorrelationOptimizer', 'itkMaxPhaseCorrelationOptimizerPCIRMIUS3IUS3', True, 'itk::PhaseCorrelationImageRegistrationMethod< itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 > >'),
  ('MaxPhaseCorrelationOptimizer', 'itk::MaxPhaseCorrelationOptimizer', 'itkMaxPhaseCorrelationOptimizerPCIRMIF3IF3', True, 'itk::PhaseCorrelationImageRegistrationMethod< itk::Image< float,3 >, itk::Image< float,3 > >'),
  ('MaxPhaseCorrelationOptimizer', 'itk::MaxPhaseCorrelationOptimizer', 'itkMaxPhaseCorrelationOptimizerPCIRMID3ID3', True, 'itk::PhaseCorrelationImageRegistrationMethod< itk::Image< double,3 >, itk::Image< double,3 > >'),
  ('Tile', 'itk::Tile', 'itkTile2', False, '2'),
  ('Tile', 'itk::Tile', 'itkTile3', False, '3'),
  ('TileConfiguration', 'itk::TileConfiguration', 'itkTileConfiguration2', True, '2'),
  ('TileConfiguration', 'itk::TileConfiguration', 'itkTileConfiguration3', True, '3'),
  ('TileMontage', 'itk::TileMontage', 'itkTileMontageISS2F', True, 'itk::Image< signed short,2 >,float'),
  ('TileMontage', 'itk::TileMontage', 'itkTileMontageIUC2F', True, 'itk::Image< unsigned char,2 >,float'),
  ('TileMontage', 'itk::TileMontage', 'itkTileMontageIUS2F', True, 'itk::Image< unsigned short,2 >,float'),
  ('TileMontage', 'itk::TileMontage', 'itkTileMontageIF2F', True, 'itk::Image< float,2 >,float'),
  ('TileMontage', 'itk::TileMontage', 'itkTileMontageID2F', True, 'itk::Image< double,2 >,float'),
  ('TileMontage', 'itk::TileMontage', 'itkTileMontageISS3F', True, 'itk::Image< signed short,3 >,float'),
  ('TileMontage', 'itk::TileMontage', 'itkTileMontageIUC3F', True, 'itk::Image< unsigned char,3 >,float'),
  ('TileMontage', 'itk::TileMontage', 'itkTileMontageIUS3F', True, 'itk::Image< unsigned short,3 >,float'),
  ('TileMontage', 'itk::TileMontage', 'itkTileMontageIF3F', True, 'itk::Image< float,3 >,float'),
  ('TileMontage', 'itk::TileMontage', 'itkTileMontageID3F', True, 'itk::Image< double,3 >,float'),
  ('NMinimaMaximaImageCalculator', 'itk::NMinimaMaximaImageCalculator', 'itkNMinimaMaximaImageCalculatorISS2', True, 'itk::Image< signed short,2 >'),
  ('NMinimaMaximaImageCalculator', 'itk::NMinimaMaximaImageCalculator', 'itkNMinimaMaximaImageCalculatorIUC2', True, 'itk::Image< unsigned char,2 >'),
  ('NMinimaMaximaImageCalculator', 'itk::NMinimaMaximaImageCalculator', 'itkNMinimaMaximaImageCalculatorIUS2', True, 'itk::Image< unsigned short,2 >'),
  ('NMinimaMaximaImageCalculator', 'itk::NMinimaMaximaImageCalculator', 'itkNMinimaMaximaImageCalculatorIF2', True, 'itk::Image< float,2 >'),
  ('NMinimaMaximaImageCalculator', 'itk::NMinimaMaximaImageCalculator', 'itkNMinimaMaximaImageCalculatorID2', True, 'itk::Image< double,2 >'),
  ('NMinimaMaximaImageCalculator', 'itk::NMinimaMaximaImageCalculator', 'itkNMinimaMaximaImageCalculatorISS3', True, 'itk::Image< signed short,3 >'),
  ('NMinimaMaximaImageCalculator', 'itk::NMinimaMaximaImageCalculator', 'itkNMinimaMaximaImageCalculatorIUC3', True, 'itk::Image< unsigned char,3 >'),
  ('NMinimaMaximaImageCalculator', 'itk::NMinimaMaximaImageCalculator', 'itkNMinimaMaximaImageCalculatorIUS3', True, 'itk::Image< unsigned short,3 >'),
  ('NMinimaMaximaImageCalculator', 'itk::NMinimaMaximaImageCalculator', 'itkNMinimaMaximaImageCalculatorIF3', True, 'itk::Image< float,3 >'),
  ('NMinimaMaximaImageCalculator', 'itk::NMinimaMaximaImageCalculator', 'itkNMinimaMaximaImageCalculatorID3', True, 'itk::Image< double,3 >'),
  ('TileMergeImageFilter', 'itk::TileMergeImageFilter', 'itkTileMergeImageFilterISS2D', True, 'itk::Image< signed short,2 >,double'),
  ('TileMergeImageFilter', 'itk::TileMergeImageFilter', 'itkTileMergeImageFilterIUC2D', True, 'itk::Image< unsigned char,2 >,double'),
  ('TileMergeImageFilter', 'itk::TileMergeImageFilter', 'itkTileMergeImageFilterIUS2D', True, 'itk::Image< unsigned short,2 >,double'),
  ('TileMergeImageFilter', 'itk::TileMergeImageFilter', 'itkTileMergeImageFilterIF2D', True, 'itk::Image< float,2 >,double'),
  ('TileMergeImageFilter', 'itk::TileMergeImageFilter', 'itkTileMergeImageFilterID2D', True, 'itk::Image< double,2 >,double'),
  ('TileMergeImageFilter', 'itk::TileMergeImageFilter', 'itkTileMergeImageFilterISS3D', True, 'itk::Image< signed short,3 >,double'),
  ('TileMergeImageFilter', 'itk::TileMergeImageFilter', 'itkTileMergeImageFilterIUC3D', True, 'itk::Image< unsigned char,3 >,double'),
  ('TileMergeImageFilter', 'itk::TileMergeImageFilter', 'itkTileMergeImageFilterIUS3D', True, 'itk::Image< unsigned short,3 >,double'),
  ('TileMergeImageFilter', 'itk::TileMergeImageFilter', 'itkTileMergeImageFilterIF3D', True, 'itk::Image< float,3 >,double'),
  ('TileMergeImageFilter', 'itk::TileMergeImageFilter', 'itkTileMergeImageFilterID3D', True, 'itk::Image< double,3 >,double'),
)
snake_case_functions = ('tile_montage', 'phase_correlation_optimizer', 'phase_correlation_image_registration_method', 'image_to_image_filter', 'max_phase_correlation_optimizer', 'phase_correlation_operator', 'tile_merge_image_filter', 'image_source', )

==> itk_montage-0.7.0-cp37-cp37m-win_amd64.whl: itk/Configuration/MontageConfig.py <==
depends = ('ITKPyBase', 'ITKTransform', 'ITKImageFrequency', 'ITKIOImageBase', 'ITKFFT', 'ITKCommon', )
templates = (
  ('Image', 'itk::Image', 'itkImageCD2', False, 'std::complex< double >, 2'),
  ('vector', 'std::vector', 'vectoritkImageCD2', False, 'itk::Image< std::complex< double >, 2  > '),
  ('Image', 'itk::Image', 'itkImageCD3', False, 'std::complex< double >, 3'),
  ('vector', 'std::vector', 'vectoritkImageCD3', False, 'itk::Image< std::complex< double >, 3  > '),
  ('ImageSource', 'itk::ImageSource', 'itkImageSourceICD2', False, 'itk::Image< std::complex< double >, 2 >'),
  ('ImageSource', 'itk::ImageSource', 'itkImageSourceICD3', False, 'itk::Image< std::complex< double >, 3 >'),
  ('ImageToImageFilter', 'itk::ImageToImageFilter', 'itkImageToImageFilterICD2ICD2', False, 'itk::Image< std::complex< double >, 2 >, itk::Image< std::complex< double >, 2 >'),
  ('ImageToImageFilter', 'itk::ImageToImageFilter', 'itkImageToImageFilterICD3ICD3', False, 'itk::Image< std::complex< double >, 3 >, itk::Image< std::complex< double >, 3 >'),
  ('PhaseCorrelationOperator', 'itk::PhaseCorrelationOperator', 'itkPhaseCorrelationOperatorF2', True, 'float, 2'),
  ('PhaseCorrelationOperator', 'itk::PhaseCorrelationOperator', 'itkPhaseCorrelationOperatorD2', True, 'double, 2'),
  ('PhaseCorrelationOperator', 'itk::PhaseCorrelationOperator', 'itkPhaseCorrelationOperatorF3', True, 'float, 3'),
  ('PhaseCorrelationOperator', 'itk::PhaseCorrelationOperator', 'itkPhaseCorrelationOperatorD3', True, 'double, 3'),
  ('PhaseCorrelationOptimizerEnums', 'itk::PhaseCorrelationOptimizerEnums', 'itkPhaseCorrelationOptimizerEnums', False),
  ('PhaseCorrelationOptimizer', 'itk::PhaseCorrelationOptimizer', 'itkPhaseCorrelationOptimizerF2', True, 'float, 2'),
  ('PhaseCorrelationOptimizer', 'itk::PhaseCorrelationOptimizer', 'itkPhaseCorrelationOptimizerD2', True, 'double, 2'),
  ('PhaseCorrelationOptimizer', 'itk::PhaseCorrelationOptimizer', 'itkPhaseCorrelationOptimizerF3', True, 'float, 3'),
  ('PhaseCorrelationOptimizer', 'itk::PhaseCorrelationOptimizer', 'itkPhaseCorrelationOptimizerD3', True, 'double, 3'),
  ('PhaseCorrelationImageRegistrationMethodEnums', 'itk::PhaseCorrelationImageRegistrationMethodEnums', 'itkPhaseCorrelationImageRegistrationMethodEnums', False),
  ('PhaseCorrelationImageRegistrationMethod', 'itk::PhaseCorrelationImageRegistrationMethod', 'itkPhaseCorrelationImageRegistrationMethodISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('PhaseCorrelationImageRegistrationMethod', 'itk::PhaseCorrelationImageRegistrationMethod', 'itkPhaseCorrelationImageRegistrationMethodIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('PhaseCorrelationImageRegistrationMethod', 'itk::PhaseCorrelationImageRegistrationMethod', 'itkPhaseCorrelationImageRegistrationMethodIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('PhaseCorrelationImageRegistrationMethod', 'itk::PhaseCorrelationImageRegistrationMethod', 'itkPhaseCorrelationImageRegistrationMethodIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('PhaseCorrelationImageRegistrationMethod', 'itk::PhaseCorrelationImageRegistrationMethod', 'itkPhaseCorrelationImageRegistrationMethodID2ID2', True, 'itk::Image< double,2 >, itk::Image< double,2 >'),
  ('PhaseCorrelationImageRegistrationMethod', 'itk::PhaseCorrelationImageRegistrationMethod', 'itkPhaseCorrelationImageRegistrationMethodISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('PhaseCorrelationImageRegistrationMethod', 'itk::PhaseCorrelationImageRegistrationMethod', 'itkPhaseCorrelationImageRegistrationMethodIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('PhaseCorrelationImageRegistrationMethod', 'itk::PhaseCorrelationImageRegistrationMethod', 'itkPhaseCorrelationImageRegistrationMethodIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('PhaseCorrelationImageRegistrationMethod', 'itk::PhaseCorrelationImageRegistrationMethod', 'itkPhaseCorrelationImageRegistrationMethodIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('PhaseCorrelationImageRegistrationMethod', 'itk::PhaseCorrelationImageRegistrationMethod', 'itkPhaseCorrelationImageRegistrationMethodID3ID3', True, 'itk::Image< double,3 >, itk::Image< double,3 >'),
  ('DataObjectDecorator', 'itk::DataObjectDecorator', 'itkDataObjectDecoratorTTD2', False, 'itk::TranslationTransform< double , 2 >'),
  ('DataObjectDecorator', 'itk::DataObjectDecorator', 'itkDataObjectDecoratorTTD3', False, 'itk::TranslationTransform< double , 3 >'),
  ('SimpleDataObjectDecorator', 'itk::SimpleDataObjectDecorator', 'itkSimpleDataObjectDecoratorPD2', False, 'itk::Point< double , 2 >'),
  ('SimpleDataObjectDecorator', 'itk::SimpleDataObjectDecorator', 'itkSimpleDataObjectDecoratorPD3', False, 'itk::Point< double , 3 >'),
  ('Tile', 'itk::Tile', 'itkTile2', False, '2'),
  ('Tile', 'itk::Tile', 'itkTile3', False, '3'),
  ('TileConfiguration', 'itk::TileConfiguration', 'itkTileConfiguration2', True, '2'),
  ('TileConfiguration', 'itk::TileConfiguration', 'itkTileConfiguration3', True, '3'),
  ('TileMontage', 'itk::TileMontage', 'itkTileMontageISS2F', True, 'itk::Image< signed short,2 >,float'),
  ('TileMontage', 'itk::TileMontage', 'itkTileMontageIUC2F', True, 'itk::Image< unsigned char,2 >,float'),
  ('TileMontage', 'itk::TileMontage', 'itkTileMontageIUS2F', True, 'itk::Image< unsigned short,2 >,float'),
  ('TileMontage', 'itk::TileMontage', 'itkTileMontageIF2F', True, 'itk::Image< float,2 >,float'),
  ('TileMontage', 'itk::TileMontage', 'itkTileMontageID2F', True, 'itk::Image< double,2 >,float'),
  ('TileMontage', 'itk::TileMontage', 'itkTileMontageISS3F', True, 'itk::Image< signed short,3 >,float'),
  ('TileMontage', 'itk::TileMontage', 'itkTileMontageIUC3F', True, 'itk::Image< unsigned char,3 >,float'),
  ('TileMontage', 'itk::TileMontage', 'itkTileMontageIUS3F', True, 'itk::Image< unsigned short,3 >,float'),
  ('TileMontage', 'itk::TileMontage', 'itkTileMontageIF3F', True, 'itk::Image< float,3 >,float'),
  ('TileMontage', 'itk::TileMontage', 'itkTileMontageID3F', True, 'itk::Image< double,3 >,float'),
  ('NMinimaMaximaImageCalculator', 'itk::NMinimaMaximaImageCalculator', 'itkNMinimaMaximaImageCalculatorISS2', True, 'itk::Image< signed short,2 >'),
  ('NMinimaMaximaImageCalculator', 'itk::NMinimaMaximaImageCalculator', 'itkNMinimaMaximaImageCalculatorIUC2', True, 'itk::Image< unsigned char,2 >'),
  ('NMinimaMaximaImageCalculator', 'itk::NMinimaMaximaImageCalculator', 'itkNMinimaMaximaImageCalculatorIUS2', True, 'itk::Image< unsigned short,2 >'),
  ('NMinimaMaximaImageCalculator', 'itk::NMinimaMaximaImageCalculator', 'itkNMinimaMaximaImageCalculatorIF2', True, 'itk::Image< float,2 >'),
  ('NMinimaMaximaImageCalculator', 'itk::NMinimaMaximaImageCalculator', 'itkNMinimaMaximaImageCalculatorID2', True, 'itk::Image< double,2 >'),
  ('NMinimaMaximaImageCalculator', 'itk::NMinimaMaximaImageCalculator', 'itkNMinimaMaximaImageCalculatorISS3', True, 'itk::Image< signed short,3 >'),
  ('NMinimaMaximaImageCalculator', 'itk::NMinimaMaximaImageCalculator', 'itkNMinimaMaximaImageCalculatorIUC3', True, 'itk::Image< unsigned char,3 >'),
  ('NMinimaMaximaImageCalculator', 'itk::NMinimaMaximaImageCalculator', 'itkNMinimaMaximaImageCalculatorIUS3', True, 'itk::Image< unsigned short,3 >'),
  ('NMinimaMaximaImageCalculator', 'itk::NMinimaMaximaImageCalculator', 'itkNMinimaMaximaImageCalculatorIF3', True, 'itk::Image< float,3 >'),
  ('NMinimaMaximaImageCalculator', 'itk::NMinimaMaximaImageCalculator', 'itkNMinimaMaximaImageCalculatorID3', True, 'itk::Image< double,3 >'),
  ('TileMergeImageFilter', 'itk::TileMergeImageFilter', 'itkTileMergeImageFilterISS2D', True, 'itk::Image< signed short,2 >,double'),
  ('TileMergeImageFilter', 'itk::TileMergeImageFilter', 'itkTileMergeImageFilterIUC2D', True, 'itk::Image< unsigned char,2 >,double'),
  ('TileMergeImageFilter', 'itk::TileMergeImageFilter', 'itkTileMergeImageFilterIUS2D', True, 'itk::Image< unsigned short,2 >,double'),
  ('TileMergeImageFilter', 'itk::TileMergeImageFilter', 'itkTileMergeImageFilterIF2D', True, 'itk::Image< float,2 >,double'),
  ('TileMergeImageFilter', 'itk::TileMergeImageFilter', 'itkTileMergeImageFilterID2D', True, 'itk::Image< double,2 >,double'),
  ('TileMergeImageFilter', 'itk::TileMergeImageFilter', 'itkTileMergeImageFilterISS3D', True, 'itk::Image< signed short,3 >,double'),
  ('TileMergeImageFilter', 'itk::TileMergeImageFilter', 'itkTileMergeImageFilterIUC3D', True, 'itk::Image< unsigned char,3 >,double'),
  ('TileMergeImageFilter', 'itk::TileMergeImageFilter', 'itkTileMergeImageFilterIUS3D', True, 'itk::Image< unsigned short,3 >,double'),
  ('TileMergeImageFilter', 'itk::TileMergeImageFilter', 'itkTileMergeImageFilterIF3D', True, 'itk::Image< float,3 >,double'),
  ('TileMergeImageFilter', 'itk::TileMergeImageFilter', 'itkTileMergeImageFilterID3D', True, 'itk::Image< double,3 >,double'),
)
snake_case_functions = ('phase_correlation_image_registration_method', 'image_source', 'image_to_image_filter', 'phase_correlation_operator', 'phase_correlation_optimizer', 'tile_merge_image_filter', 'tile_montage', )
